/*****************************************************************************
 * File:			wifly.h
 * Description:		Driver WiFly RN-XV
 *
 * Author:			Sergio Gómez
 *****************************************************************************/

#ifndef WIFLY_H_
#define WIFLY_H_

#define UART_WIFLY			(UARTPORT_WIFLY)
#define RST_WIFLY_PIN		22
#define CONN_FAILURE_MAX	5		//Number of failure connections before reset WiFly

/* Timeouts	*/
#define TIME_SET			500		//Time for set commands
#define TIME_GET			500		//Time for get commands
#define TIME_CONNECT		5000	//Time for join
#define	TIME_PING			5000	//Time for ping
#define TIME_SHOW			1000	//Time for show commands
#define TIME_TCPOPEN		1000	//Time for TCP Open connection

/* Authentication Type */
#define OPEN				0
#define WEP					1
#define WPA					2

/* Host Type */
#define HOSTDNS				0
#define HOSTIP				1

void wiflyInit(uint32_t BaudRate);
void wiflyReset(void);
uint8_t wiflyConnectSSID(char* SSID, uint32_t AuthType, char* Pass);
uint8_t wiflyPing(char* Host);
void wiflyReportConnFailure();

/** Get Functions **/
void wiflyGetIP(char *string);
uint32_t wiflyGetChannel();
uint32_t wiflyGetRSSI();
uint32_t wiflyGetUpTime();
uint32_t wiflyGetTxPower();
void wiflyGetTCPConfig(char *IP, char *Host, uint32_t *Port);

/** Set Functions **/
uint8_t wiflySetTxPower(uint32_t Power);
void wiflySetTCPConfig(uint8_t HostType, char* Host, uint32_t Port);

/** TCP Socket Functions **/
uint8_t wiflyTCPOpen();
void wiflySendDataSocket(char* data);
void wiflyGetDataSocket(char *data, uint32_t timeout);

#endif /* WIFLY_H_ */
