/*****************************************************************************
 * File:			buzzer.c
 * Description:		Controla el buzzer connectat a un pin GPIO
 *
 * Author:			Sergio Gómez
 *****************************************************************************/

/* LPC Includes */
#include "LPC17xx.h"
#include "type.h"

/* Library Includes */
#include "gpio.h"
#include "buzzer.h"

/*****************************************************************************
 * Function:		buzzerInit
 * Description:		Inicialitza el buzzer. Inicialitza i configura el port GPIO
 * 					on està connectat el buzzer.
 *
 * @return			None
 *****************************************************************************/
void buzzerInit(void){

	GPIOInitPin(BUZZER_PINSEL_NUMBER, BUZZER_PINSEL_FIRSTBIT);
	GPIOSetPinDirection(BUZZER_GPIO_PORT, BUZZER_GPIO_BIT, OUTPUT);
}

/*****************************************************************************
 * Function:		buzzerOn
 * Description:		Posa en marxa el buzzer
 *
 * @return			None
 *****************************************************************************/
void buzzerOn( void ){
	GPIOSetPinHigh(BUZZER_GPIO_PORT, BUZZER_GPIO_BIT);
}

/*****************************************************************************
 * Function:		buzzerOff
 * Description:		Apaga el buzzer
 *
 * @return			None
 *****************************************************************************/
void buzzerOff( void ){
	GPIOSetPinLow(BUZZER_GPIO_PORT, BUZZER_GPIO_BIT);
}

/*****************************************************************************
 * Function:		buzzerToggle
 * Description:		Encèn el buzzer si està apagat, i l'apaga si està encès.
 *
 * @return			None
 *****************************************************************************/
void buzzerToggle( void ){

	uint8_t state;

	/* Obté l'estat actual del PIN */
	state = GPIOGetPinState(BUZZER_GPIO_PORT, BUZZER_GPIO_BIT);

	if (state==HIGH){	//Buzzer is ON
		buzzerOff();
	} else {			//Buzzer is OFF
		buzzerOn();
	}
}
