/*****************************************************************************
 * File:			commonUtils.c
 * Description:		Llibreria amb funcions comunes
 *
 * Author:			Sergio Gómez
 *****************************************************************************/

/* FreeRTOS Includes */
#include "FreeRTOS.h"
#include "task.h"

/* LPC Includes */
#include "LPC17xx.h"
#include "type.h"

/* Library Includes */
#include "commonUtils.h"

/* Private Functions */
int Base64encode_len(int len);


/*****************************************************************************
 * Function:		vDelayMs
 * Description:		Realitza una espera activa o passiva, segons paràmetre
 *
 * @param[in]		DelayType	ACTIVE (0) o PASSIVE (1)
 * @param[in]		ms:			Temps d'espera (milisegons)
 *
 * @return			None
 *****************************************************************************/
void vDelayMs(uint32_t DelayType, uint32_t ms){
	uint32_t i;

	switch (DelayType) {
		case 0:	//Active Delay
			for (i=0; i<((uint32_t)7140*ms); i++);		//7140 iterations are 1ms
			break;

		case 1:	//Passive Delay
			vTaskDelay(ms / portTICK_RATE_MS);
			break;
	}
}


/*****************************************************************************
 * Function:		Base64encode
 * Description:		Codifica una cadena en BASE64
 *
 * @param[out]		encoded		Text de sortida en BASE64
 * @param[in]		string		Punter que conté el text en clar a convertir
 * @param[in]		len			Longitud de la cadena a convertir
 *
 * @return			None
 *****************************************************************************/
/* Base64 encoder/decoder. Originally Apache file ap_base64.c
 * http://www.opensource.apple.com/source/QuickTimeStreamingServer/QuickTimeStreamingServer-452/CommonUtilitiesLib/base64.c
 * @APPLE_LICENSE_HEADER_START@
 *
 * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this
 * file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_LICENSE_HEADER_END@
 */
int Base64encode(char *encoded, const char *string, int len)
{
	const char basis_64[] =
	    "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";

    int i;
    char *p;

    p = encoded;
    for (i = 0; i < len - 2; i += 3) {
    *p++ = basis_64[(string[i] >> 2) & 0x3F];
    *p++ = basis_64[((string[i] & 0x3) << 4) |
                    ((int) (string[i + 1] & 0xF0) >> 4)];
    *p++ = basis_64[((string[i + 1] & 0xF) << 2) |
                    ((int) (string[i + 2] & 0xC0) >> 6)];
    *p++ = basis_64[string[i + 2] & 0x3F];
    }
    if (i < len) {
    *p++ = basis_64[(string[i] >> 2) & 0x3F];
    if (i == (len - 1)) {
        *p++ = basis_64[((string[i] & 0x3) << 4)];
        *p++ = '=';
    }
    else {
        *p++ = basis_64[((string[i] & 0x3) << 4) |
                        ((int) (string[i + 1] & 0xF0) >> 4)];
        *p++ = basis_64[((string[i + 1] & 0xF) << 2)];
    }
    *p++ = '=';
    }

    *p++ = '\0';
    return p - encoded;
}

int Base64encode_len(int len)
{
    return ((len + 2) / 3 * 4) + 1;
}
