/*****************************************************************************
 * File:			tmp102.c
 * Description:		Driver sensor de temperatura TMP102 Texas Instruments
 *
 * Author:			Sergio Gómez
 *****************************************************************************/

/* FreeRTOS Includes */
#include "FreeRTOS.h"	//Nedded?

/* LPC Includes */
#include "LPC17xx.h"
#include "type.h"

/* Library Includes */
#include "config.h"
#include "debug.h"
#include "i2c.h"
#include "tmp102.h"
#include "commonUtils.h"

#include <stdio.h>	//Required for: sprintf

/* Variables definides al driver I2C */
extern volatile uint8_t I2CMasterBuffer[I2C_PORT_NUM][BUFSIZE];
extern volatile uint8_t I2CSlaveBuffer[I2C_PORT_NUM][BUFSIZE];
extern volatile uint32_t I2CReadLength[I2C_PORT_NUM];
extern volatile uint32_t I2CWriteLength[I2C_PORT_NUM];

/*****************************************************************************
 * Function:		tmp102Init
 * Description:		Inicialitza el port I2C utilitzat pel sensor.
 *
 * @return			None
 *****************************************************************************/
void tmp102Init(void){

	/* SystemClockUpdate() updates the SystemFrequency variable */
	SystemCoreClockUpdate();

	//Inicialització I2C
	switch(PORT_USED){
		case 0:
			I2C0Init( );
			break;

		case 1:
			I2C1Init( );
			break;

		case 2:
			I2C2Init( );
			break;
	}
}

/*****************************************************************************
 * Function:		tmp102GetTemp
 * Description:		Obté una mesura de temperatura del sensor
 *
 * @return			Temperatura obtinguda (float)
 *****************************************************************************/
float tmp102GetTemp(void){

	int lecturaI2C, i;
	float temp;
	uint8_t MSB, LSB;

	/* Apuntem al registre de temperatura del sensor */
	I2CWriteLength[PORT_USED] = 2;				//Escriurem 2 bytes
	I2CReadLength[PORT_USED] = 0;				//Llegirem 0 bytes
	I2CMasterBuffer[PORT_USED][0] = TMP102_WR;	//Adreça I2C del sensor + Write Bit
	I2CMasterBuffer[PORT_USED][1] = TEMP_REG;	//Seleccionem el registre de temperatura del sensor
	I2CEngine(PORT_USED);						//Executem la transmissió I2C

	//for ( i = 0; i < 0x200000; i++ );			/* Delay after write */
	vDelayMs(ACTIVE, 30);						// Delay 30ms after write

	/* Buidem el byffer */
	for ( i = 0; i < BUFSIZE; i++ )
	{
		I2CSlaveBuffer[PORT_USED][i] = 0x00;
	}

	/* Obtenim la temperatura sel sensor */
	I2CWriteLength[PORT_USED] = 1;				//Escriurem 1 byte
	I2CReadLength[PORT_USED] = 2;				//Llegirem 2 bytes
	I2CMasterBuffer[PORT_USED][0] = TMP102_RD;	//Adreça I2C del sensor + Read Bit
	I2CEngine(PORT_USED);						//Executem la transmissió I2C

	vDelayMs(ACTIVE, 30);						// Delay 30ms after write

	/* Obtenim els 2 bytes llegits */
	MSB = I2CSlaveBuffer[PORT_USED][0];			//Most Significant Bit
	LSB = I2CSlaveBuffer[PORT_USED][1];			//Least Significant Bit

	/* Conversió dels 12 bits a integer */
	lecturaI2C = ((MSB << 8) | LSB) >> 4;

	/* Obtenim la dada de temperatura */
	temp = lecturaI2C*0.0625;					//Datasheet

	/**
	 * Exemple:
	 *
	 *    23: 00010111	(MSB)
	 *    16: 00010000	(LSB)
	 *    23 << 8    = 00010111 00000000
	 *    OR 16      =          00010000
	 *               = 00010111 00010000
	 *    >> 4	     =     0001 01110001  (369)
	 *
	 *    369 x 0.0625 = 23.0625 ºC
	 */

	return temp;
}
